@@ -1,4 +1,5 @@
 import shlex, re, os, shutil, logging
+import threading, io, time, tempfile
 import subprocess as sp
 from collections import abc
 from . import filter_utils
@@ -70,28 +71,12 @@ def parse_options(args):
 
 
 def parse(cmdline):
-    """Parse ffmpeg command line arguments:
-
-    `[_global_options] {[input_file_options] -i input_url} ... {[output_file_options] output_url} ...`
-
-    Argument
-    cmdline : str
-        ffmpeg command line string or partial argument thereof
-
-    Returns
-        dict : parsed command fields
-
-        dict["_global_options"] : dict
-        dict["inputs"] : a list of tuples for inputs: (input_url, input_file_options)
-        dict["outputs"] : a list of tuples for outputs : (output_url, output_file_options)
-
-        Any xxx_options item is a dict with the option argument (minus the leading dash, possibly with stream id) as the key and
-        its option value as the dict element value. If option is a flag, its value is None.
-
-    Caution: multiple output_url's are detected based on the assumption that the last output file option of each output_url
-    requires a value unless the option is one of the flag option listed in `_output_flags`. If an unlisted flag option is used
-    add it to appear as an earlier output options.
+    """parse ffmpeg command line arguments
 
+    :param cmdline: full or partial ffmpeg command line string
+    :type cmdline: str
+    :return: ffmpegio FFmpeg argument dict
+    :rtype: dict
     """
 
     # remove multi-line command
@@ -362,67 +347,108 @@ def _get_ffmpeg(probe=False):
 
 
 def run_sync(
-    args,
+    ffmpeg_args,
     *sp_arg,
     hide_banner=True,
     stdout=PIPE,
     stderr=PIPE,
     **sp_kwargs,
 ):
-    """run ffmpeg synchronously as a subprocess (block until completion)
+    """run ffmpeg command as a subprocess (blocking)
 
-    :param args: command-less FFmpeg arguments
-    :type args: seq or dict
+    :param ffmpeg_args: FFmpeg argument options
+    :type ffmpeg_args: dict, seq, or str
     :param hide_banner: False to output ffmpeg banner in stderr, defaults to True
     :type hide_banner: bool, optional
-    :param stdout: subprocess stdout mode, defaults to ffmpegio.PIPE
-    :type stdout: [type], optional
-    :param stderr: subprocess stderr mode, defaults to ffmpegio.PIPE
-    :type stderr: [type], optional
-    :raises Exception: [description]
-    :return: [description]
-    :rtype: [type]
+    :return: log of the completed FFmpeg run
+    :rtype: str
     """
-    if isinstance(args, dict):
-        args = compose(**args, command=_get_ffmpeg())
+    if isinstance(ffmpeg_args, dict):
+        ffmpeg_args = compose(**ffmpeg_args, command=_get_ffmpeg())
     else:
-        args = [_get_ffmpeg(), *(shlex.split(args) if isinstance(args, str) else args)]
+        ffmpeg_args = [
+            _get_ffmpeg(),
+            *(
+                shlex.split(ffmpeg_args)
+                if isinstance(ffmpeg_args, str)
+                else ffmpeg_args
+            ),
+        ]
 
     if hide_banner:
-        args.insert(1, "-hide_banner")
+        ffmpeg_args.insert(1, "-hide_banner")
 
-    logging.debug(args)
+    logging.debug(ffmpeg_args)
 
-    ret = sp.run(args, *sp_arg, stdout=stdout, stderr=stderr, **sp_kwargs)
+    ret = sp.run(ffmpeg_args, *sp_arg, stdout=stdout, stderr=stderr, **sp_kwargs)
     if ret.returncode != 0 and ret.stderr is not None:
         msg = ret.stderr
         try:
             msg = msg.decode("utf-8")
         finally:
-            raise Exception(f"execution failed\n   {form_shell_cmd(args)}\n\n{msg}")
+            raise Exception(
+                f"execution failed\n   {form_shell_cmd(ffmpeg_args)}\n\n{msg}"
+            )
 
     return ret.stderr if ret.stdout is None else ret.stdout
 
 
 def run(
-    args,
+    ffmpeg_args,
     *sp_arg,
+    progress=None,
     hide_banner=True,
     stdout=PIPE,
     stderr=PIPE,
     **sp_kwargs,
 ):
-    if isinstance(args, dict):
-        args = compose(**args, command=_get_ffmpeg())
+    """start FFmpeg subprocess (non-blocking)
+
+    :param ffmpeg_args: FFmpeg argument options
+    :type ffmpeg_args: dict, seq, or str
+    :param progress: progress callback function, defaults to None
+    :type progress: function, optional
+    :param hide_banner: False to output ffmpeg banner in stderr, defaults to True
+    :type hide_banner: bool, optional
+    :return: Python subprocess Popen object to monitor/interact with the FFmpeg process
+    :rtype: subprocess.Popen
+    """
+    if isinstance(ffmpeg_args, dict):
+        ffmpeg_args = compose(**ffmpeg_args, command=_get_ffmpeg())
     else:
-        args = [_get_ffmpeg(), *(shlex.split(args) if isinstance(args, str) else args)]
+        ffmpeg_args = [
+            _get_ffmpeg(),
+            *(
+                shlex.split(ffmpeg_args)
+                if isinstance(ffmpeg_args, str)
+                else ffmpeg_args
+            ),
+        ]
 
     if hide_banner:
-        args.insert(1, "-hide_banner")
+        ffmpeg_args.insert(1, "-hide_banner")
 
-    logging.debug(form_shell_cmd(args))
+    if progress:
+        progress_monitor = _ProgressMonitor(progress)
+        ffmpeg_args = [
+            *ffmpeg_args[:1],
+            "-progress",
+            progress_monitor.url,
+            *ffmpeg_args[1:],
+        ]
 
-    return sp.Popen(args, *sp_arg, stdout=stdout, stderr=stderr, **sp_kwargs)
+    logging.debug(form_shell_cmd(ffmpeg_args))
+
+    proc = sp.Popen(ffmpeg_args, *sp_arg, stdout=stdout, stderr=stderr, **sp_kwargs)
+
+    # stderr_monitor = _StderrMonitor(proc)
+    # stderr_monitor.start()
+
+    if progress:
+        progress_monitor.proc = proc
+        progress_monitor.start()
+
+    return proc
 
 
 def ffprobe(
@@ -435,7 +461,15 @@ def ffprobe(
     hide_banner=True,
     **sp_kwargs,
 ):
+    """run ffprobe command as a subprocess (blocking)
 
+    :param args: ffprobe argument options
+    :type args: seq or str
+    :param hide_banner: False to output ffmpeg banner, defaults to True
+    :type hide_banner: bool, optional
+    :return: ffprobe stdout output
+    :rtype: str
+    """
     args = [
         _get_ffmpeg(probe=True),
         *(["-hide_banner"] if hide_banner else []),
@@ -494,3 +528,128 @@ def versions():
                 lv = v["library_versions"] = {}
             lv[m[1]] = m[2].replace(" ", "")
     return v
+
+
+class _ProgressMonitor(threading.Thread):
+    def __init__(self, callback, initial_wait=0.5):
+        threading.Thread.__init__(self)
+        self._td = tempfile.TemporaryDirectory()
+        self.url = os.path.join(self._td.name, "progress.txt")
+        self.callback = callback
+        self.initial_wait = initial_wait
+        self.proc = None
+
+    def run(self):
+        proc = self.proc
+        url = self.url
+        callback = self.callback
+
+        def readnext(f):
+            txt = f.readline()
+            m = pattern.match(txt)
+            while not m:
+                txt = f.readline()
+                m = pattern.match(txt)
+            return m
+
+        pattern = re.compile(r"(.+)?=(.+)\n")
+        done = False
+        logging.debug(f'[progress_monitor] monitoring "{url}"')
+        time.sleep(self.initial_wait)
+        if proc.poll() is None and os.path.isfile(url):
+            logging.debug(f"[progress_monitor] file found")
+            with open(url, "rt") as f:
+                while proc.poll() is None and not done:
+                    d = {}
+                    m = readnext(f)
+                    while m[1] != "progress":
+                        d[m[1]] = m[2]
+                        m = readnext(f)
+                    done = m[2] == "end"
+                    if callback(d, done):
+                        proc.terminate()
+                        proc.stderr.write("Operation canceled by user agent")
+
+        self._td.cleanup()
+
+
+class _StderrMonitorIO(io.StringIO):
+    def __init__(self):
+        io.StringIO.__init__(self)
+        self.lock = threading.Lock()
+
+    def read(self, size=-1):
+        self.lock.acquire()
+        v = io.StringIO.read(self, size)
+        self.lock.release()
+        return v
+
+    def readline(self, size=-1):
+        self.lock.acquire()
+        v = io.StringIO.readline(self, size)
+        self.lock.release()
+        return v
+
+    def write(self, s):
+        self.lock.acquire()
+        pos = io.StringIO.tell(self)
+        n = io.StringIO.write(self, s)
+        io.StringIO.seek(self, pos)
+        self.lock.release()
+        return n
+
+    def seek(self, offset, whence=io.SEEK_SET):
+        self.lock.acquire()
+        pos = io.StringIO.seek(self, offset, whence)
+        self.lock.release()
+        return pos
+
+    def tell(self):
+        self.lock.acquire()
+        pos = io.StringIO.tell(self)
+        self.lock.release()
+        return pos
+
+
+class _StderrMonitor(threading.Thread):
+    def __init__(self, proc):
+        threading.Thread.__init__(self)
+        self.proc = proc
+        self.input = proc.stderr
+        self.output = _StderrMonitorIO()
+        self.monitoring = True
+        setattr(proc, "stderr", self.output)
+
+        self.error_message = None
+        proc._stderr_monitor = self
+
+        def get_errmsg():
+            if self.proc.returncode != 0:
+                while self.monitoring:
+                    time.sleep(0.05)
+                txt = self.output.getvalue().splitlines()
+                self.error_message = txt[-1]
+            return self.error_message
+
+        setattr(proc, "get_errmsg", get_errmsg)
+
+    def run(self):
+        proc = self.proc
+        input = self.input
+
+        if input is None:
+            return
+
+        def read_next():
+            txt = input.readline().decode("utf-8")
+            if txt and txt != "\n":
+                self.output.write(txt)
+            return txt
+
+        while proc.poll() is None:
+            read_next()
+
+        while read_next():
+            pass
+
+        self.monitoring = False
